class ParserTest:
    def __init__(self, name: str, type: str, version: str):
        self.name = name
        self.type = type
        self.version = version
        self.description = None
